@@ -4,6 +4,9 @@ Module GTKTABLE -- Python GTK Table Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
 Copyright (C) 2008 by Peter A. Donis
 
+Released under the GNU General Public License, Version 2
+See the LICENSE and README files for more information
+
 This module contains the GTK GUI objects for the table widgets.
 """
 
@@ -27,10 +30,19 @@ class PGtkTableEntry(gtk.Entry, _PGtkCommunicator):
         self._t = table
         self._r = row
         self._c = col
-        self.setup_notify(SIGNAL_WIDGETCHANGED, self.entrychanged)
+        self._initialized = False # hack to get around index out of range on startup
+        
+        # The 'table cell changed' signal gets spotted here and forwarded
+        self.connect("changed", self.entrychanged)
     
     def entrychanged(self, obj):
-        self._t.do_notify(SIGNAL_TABLECHANGED, self._r, self._c)
+        # FIXME: Figure out why this hack is necessary to avoid index out of range
+        # on initial startup when the first changed event fires
+        if self._initialized:
+            self._t.do_notify(SIGNAL_TABLECHANGED, self._r, self._c)
+        else:
+            # First time setting the value, we can now fire the event next time
+            self._initialized = True
 
 class PGtkTableFrame(gtk.Frame):
     """ Frame to draw border around cell entry and label widgets. """
@@ -52,7 +64,6 @@ class PGtkTableLabels(table.PTableLabelsBase):
         if len(self.table.widgets) == 0:
             self.table._attach_widget(0, 0, PGtkTableFrame(gtk.Label()))
         table.PTableLabelsBase._update(self, data)
-        #table.PTableLabelsBase.dodisplay(self)
     
     def _set_label(self, index, label):
         self.table._attach_widget(0, index + 1, PGtkTableFrame(gtk.Label(label)))
@@ -66,7 +77,7 @@ class PGtkTableLabels(table.PTableLabelsBase):
     def _set_readonly(self, index, readonly):
         pass
 
-class PGtkTable(gtk.Table, table.PTableBase, _PGtkWidget):
+class PGtkTable(gtk.Table, _PGtkWidget, table.PTableBase):
     
     labelsclass = PGtkTableLabels
     
@@ -75,9 +86,8 @@ class PGtkTable(gtk.Table, table.PTableBase, _PGtkWidget):
         (gobject.SIGNAL_RUN_LAST,
         gobject.TYPE_NONE, (gobject.TYPE_INT, gobject.TYPE_INT)) }
     
-    def __init__(self, parent, labels=None, objlist=None, target=None):
-        """ Expects labels to be a list of PLabels (PLabel will be defined
-        in PGUI.PY). """
+    def __init__(self, parent, labels=None, data=None, target=None):
+        """ Expects labels to be a list of PLabels. """
         
         self._l = labels
         self._r = 0
@@ -86,7 +96,7 @@ class PGtkTable(gtk.Table, table.PTableBase, _PGtkWidget):
         self.rowlabels = {}
         gtk.Table.__init__(self, self._r + 1, self._c + 1)
         _PGtkWidget.__init__(self, parent, ALIGN_JUST)
-        table.PTableBase.__init__(self, parent, labels, objlist, target)
+        table.PTableBase.__init__(self, parent, labels, data, target)
     
     # We have to override gtk.Table's Python container methods since they
     # iterate over cells instead of rows
