@@ -4,6 +4,9 @@ Module QTAPP -- Python Qt Application Objects
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
 Copyright (C) 2008 by Peter A. Donis
 
+Released under the GNU General Public License, Version 2
+See the LICENSE and README files for more information
+
 This module contains the Qt GUI application objects.
 """
 
@@ -93,7 +96,9 @@ class _PQtMainMixin(qt.QMainWindow, _PQtCommunicator):
     def closeEvent(self, event):
         # 'automagic' code for SIGNAL_QUERYCLOSE
         if self.acceptclose():
-            self._emit_event(SIGNAL_QUERYCLOSE)
+            # FIXME: either figure a way to emit this signal first, before acceptclose(),
+            # or change it to SIGNAL_BEFORECLOSE
+            #self._emit_event(SIGNAL_QUERYCLOSE)
             event.accept()
         else:
             event.ignore()
