@@ -4,6 +4,9 @@ Module WXTABWIDGET -- Python wxWidgets Tab Widget
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
 Copyright (C) 2008 by Peter A. Donis
 
+Released under the GNU General Public License, Version 2
+See the LICENSE and README files for more information
+
 This module contains the wxWidgets GUI objects for the tab widget.
 """
 
@@ -16,11 +19,11 @@ from _wxcommon import _PWxCommunicator
 
 class PWxTabWidget(wx.Notebook, tabwidget.PTabWidgetBase, _PWxCommunicator):
     
-    def __init__(self, parent, tabs=None):
+    def __init__(self, parent, tabs=None, target=None):
         wx.Notebook.__init__(self, parent)
         self._align = ALIGN_JUST # used by PWxPanel to determine placement
         self._expand = True
-        tabwidget.PTabWidgetBase.__init__(self, tabs)
+        tabwidget.PTabWidgetBase.__init__(self, parent, tabs, target)
     
     def __len__(self):
         return self.GetPageCount()
