@@ -4,6 +4,9 @@ Module DEFS -- Common GUI Definitions
 Sub-Package GUI of Package PLIB -- Python GUI Framework
 Copyright (C) 2008 by Peter A. Donis
 
+Released under the GNU General Public License, Version 2
+See the LICENSE and README files for more information
+
 Defines common constants and functions used by various GUI modules.
 """
 
@@ -49,17 +52,21 @@ PANEL_RAISED = 2
 PANEL_SUNKEN = 3
 
 # constants for signals
-SIGNAL_ACTIVATED = 10
-SIGNAL_CLICKED = 101
-SIGNAL_TOGGLED = 102
-SIGNAL_LISTVIEWCHANGED = 201
-SIGNAL_TABLECHANGED = 301
-SIGNAL_TEXTCHANGED = 401
-SIGNAL_ENTER = 490
-SIGNAL_WIDGETCHANGED = 901
-SIGNAL_QUERYCLOSE = 991
-SIGNAL_HIDDEN = 995
-SIGNAL_BEFOREQUIT = 999
+SIGNAL_ACTIVATED = 10 # widget has received focus
+SIGNAL_CLICKED = 101 # widget has been clicked
+SIGNAL_TOGGLED = 102 # on/off widget has been toggled
+SIGNAL_SELECTED = 151 # item in widget has been selected; handler must take index param
+SIGNAL_LISTVIEWCHANGED = 201 # list view item has changed; handler must take item param
+SIGNAL_TABLECHANGED = 301 # table cell text has changed; handler must take row, col params
+SIGNAL_TEXTCHANGED = 401 # text in widget has been changed
+SIGNAL_ENTER = 490 # enter/return key has been pressed while widget has focus
+SIGNAL_TABCHANGED = 501 # new tab has been selected; handler must take widget param
+SIGNAL_WIDGETCHANGED = 901 # widget has been changed (not including above specific changes)
+SIGNAL_HIDDEN = 951 # widget has been hidden
+
+# these signal constants are for internal use only
+SIGNAL_QUERYCLOSE = 991 # widget is asking permission to close
+SIGNAL_BEFOREQUIT = 999 # app is about to quit
 
 # constants for action flags, used as keys
 ACTION_FILENEW = 1
